Index: trunk/psLib/src/image/psImageIO.h
===================================================================
--- trunk/psLib/src/image/psImageIO.h	(revision 1442)
+++ trunk/psLib/src/image/psImageIO.h	(revision 2204)
@@ -10,6 +10,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.7 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-08-10 01:05:53 $
+ *  @version $Revision: 1.8 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -17,6 +17,4 @@
 #ifndef PS_IMAGEIO_H
 #define PS_IMAGEIO_H
-
-#include <stdbool.h>
 
 #include "psImage.h"
@@ -34,17 +32,17 @@
     /**< the output psImage to recycle, or NULL if new psImage desired */
 
-    int col0,
+    psS32 col0,
     /**< the column index of the origin to start reading */
 
-    int row0,
+    psS32 row0,
     /**< the row index of the origin to start reading */
 
-    int numCols,
+    psS32 numCols,
     /**< the number of desired columns to read */
 
-    int numRows,
+    psS32 numRows,
     /**< the number of desired rows to read */
 
-    int z,
+    psS32 z,
     /**< the z index to read if file is organized as a 3D image cube. */
 
@@ -54,5 +52,5 @@
         */
 
-    int extnum,
+    psS32 extnum,
     /**< the image extension to read (0=PHU, 1=first extension, etc.)  This is
         *   only used if extname is NULL
@@ -65,17 +63,17 @@
 /** Read an image or subimage from a FITS file specified by a filename.
  *
  *  return bool         TRUE is successful, otherwise FALSE.
  */
-bool psImageWriteSection(
+psBool psImageWriteSection(
     psImage* input,
     /**< the psImage to write */
 
-    int col0,
+    psS32 col0,
     /**< the column index of the origin to start writing */
 
-    int row0,
+    psS32 row0,
     /**< the row index of the origin to start writing */
 
-    int z,
+    psS32 z,
     /**< the z index to start writing */
 
@@ -85,5 +83,5 @@
     */
 
-    int extnum,
+    psS32 extnum,
     /**< the image extension to write (0=PHU, 1=first extension, etc.)  This is
     *   only used if extname is NULL.
@@ -65,17 +63,17 @@
 /** Read an image or subimage from a FITS file specified by a filename.
  *
- *  return bool         TRUE is successful, otherwise FALSE.
+ *  return psBool         TRUE is successful, otherwise FALSE.
  */
